.. Copyright (C) 2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _dep:

DebOps Enhancement Proposals
============================

.. toctree::
   :maxdepth: 1
   :glob:

   dep-*

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
